package com.temboo.Library.Facebook.Reading;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetLatestPrivateMessage

Retrieves the latest private message in a user's inbox.
*/
public class GetLatestPrivateMessage extends Choreography {

	/**
	Create a new instance of the GetLatestPrivateMessage Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetLatestPrivateMessage(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Facebook/Reading/GetLatestPrivateMessage"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetLatestPrivateMessageInputSet
	*/
	public GetLatestPrivateMessageInputSet newInputSet() {
		return new GetLatestPrivateMessageInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetLatestPrivateMessageResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetLatestPrivateMessageResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetLatestPrivateMessage
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetLatestPrivateMessageInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved from the final step of the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the ProfileID input for this Choreo. 

		@param String - (optional, string) The id of the profile to retrieve the latest message for. Defaults to "me" indicating the authenticated user.
		*/
		public void set_ProfileID(String value) {
			this.setInput("ProfileID", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetLatestPrivateMessage Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetLatestPrivateMessageResultSet extends ResultSet {
		public GetLatestPrivateMessageResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "CreatedTime" output from this Choreo execution

		@return String - (date) The date that the latest message was created.
		*/
		public String get_CreatedTime() {
			return this.getResultString("CreatedTime");
		}
		/** 
		Retrieve the value for the "FromID" output from this Choreo execution

		@return String - (string) The ID of the message sender.
		*/
		public String get_FromID() {
			return this.getResultString("FromID");
		}
		/** 
		Retrieve the value for the "FromName" output from this Choreo execution

		@return String - (string) The name of the message sender.
		*/
		public String get_FromName() {
			return this.getResultString("FromName");
		}
		/** 
		Retrieve the value for the "ID" output from this Choreo execution

		@return String - (string) The ID of the message.
		*/
		public String get_ID() {
			return this.getResultString("ID");
		}
		/** 
		Retrieve the value for the "Message" output from this Choreo execution

		@return String - (string) The latest private message.
		*/
		public String get_Message() {
			return this.getResultString("Message");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Facebook. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
