package com.temboo.Library.Google.Gmailv2.Drafts;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreateDraft

Creates a new draft with the DRAFT label.
*/
public class CreateDraft extends Choreography {

	/**
	Create a new instance of the CreateDraft Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreateDraft(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/Gmailv2/Drafts/CreateDraft"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreateDraftInputSet
	*/
	public CreateDraftInputSet newInputSet() {
		return new CreateDraftInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreateDraftResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreateDraftResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreateDraft
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreateDraftInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AttachmentContentType input for this Choreo. 

		@param String - (optional, string) The Content-Type of the attachment. This is required when providing AttachmentFileContent (e.g., image/jpeg, text/plain, etc).
		*/
		public void set_AttachmentContentType(String value) {
			this.setInput("AttachmentContentType", value);
		}


		/** 
		Set the value of the AttachmentFileContent input for this Choreo. 

		@param String - (optional, string) The Base64 encoded file content for the attachment. You must specify the AttachmentFileContentType when including an attachment.
		*/
		public void set_AttachmentFileContent(String value) {
			this.setInput("AttachmentFileContent", value);
		}


		/** 
		Set the value of the AttachmentFileName input for this Choreo. 

		@param String - (optional, string) The file name of the attachment.
		*/
		public void set_AttachmentFileName(String value) {
			this.setInput("AttachmentFileName", value);
		}


		/** 
		Set the value of the BCC input for this Choreo. 

		@param String - (optional, string) The address and name (optional) that should be bcc'd e.g., Dan <dan@temboo.com>.
		*/
		public void set_BCC(String value) {
			this.setInput("BCC", value);
		}


		/** 
		Set the value of the CC input for this Choreo. 

		@param String - (optional, string) The address and name (optional) that should be cc'd e.g., Dan <dan@temboo.com>.
		*/
		public void set_CC(String value) {
			this.setInput("CC", value);
		}


		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}


		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}


		/** 
		Set the value of the Fields input for this Choreo. 

		@param String - (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
		*/
		public void set_Fields(String value) {
			this.setInput("Fields", value);
		}


		/** 
		Set the value of the From input for this Choreo. 

		@param String - (conditional, string) The address and name (optional) that the email is being sent from e.g., Dan <dan@temboo.com>.
		*/
		public void set_From(String value) {
			this.setInput("From", value);
		}


		/** 
		Set the value of the MessageBody input for this Choreo. 

		@param String - (conditional, string) The text for the message body of the email.
		*/
		public void set_MessageBody(String value) {
			this.setInput("MessageBody", value);
		}


		/** 
		Set the value of the MessageBodyContentType input for this Choreo. 

		@param String - (optional, string) The Content-Type of the message body. Defaults to "text/plain; charset=UTF-8".
		*/
		public void set_MessageBodyContentType(String value) {
			this.setInput("MessageBodyContentType", value);
		}


		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}


		/** 
		Set the value of the ReplyTo input for this Choreo. 

		@param String - (optional, string) An email address to set as the Reply-To address.
		*/
		public void set_ReplyTo(String value) {
			this.setInput("ReplyTo", value);
		}


		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (conditional, string) The email subject.
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}


		/** 
		Set the value of the ThreadID input for this Choreo. 

		@param String - (optional, string) The ID of the thread the message belongs to.
		*/
		public void set_ThreadID(String value) {
			this.setInput("ThreadID", value);
		}


		/** 
		Set the value of the To input for this Choreo. 

		@param String - (conditional, string) The address and name (optional) that the email is being sent to e.g., Dan <dan@temboo.com>.
		*/
		public void set_To(String value) {
			this.setInput("To", value);
		}


		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreateDraft Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreateDraftResultSet extends ResultSet {
		public CreateDraftResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResultString("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
