package com.temboo.Library.Instagram;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ModifyRelationship

Modifies the relationship between the authenticating user and the target user.
*/
public class ModifyRelationship extends Choreography {

	/**
	Create a new instance of the ModifyRelationship Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ModifyRelationship(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Instagram/ModifyRelationship"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ModifyRelationshipInputSet
	*/
	public ModifyRelationshipInputSet newInputSet() {
		return new ModifyRelationshipInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ModifyRelationshipResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ModifyRelationshipResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ModifyRelationship
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ModifyRelationshipInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (required, string) The access token retrieved during the OAuth 2.0 process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the Action input for this Choreo. 

		@param String - (required, string) The type of relationship modification to perform. Valid values are: follow, unfollow, block, unblock, approve, or deny.
		*/
		public void set_Action(String value) {
			this.setInput("Action", value);
		}


		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (required, string) The ID of the target user.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ModifyRelationship Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ModifyRelationshipResultSet extends ResultSet {
		public ModifyRelationshipResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Instagram.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
